#!/usr/bin/env bash
echo 'Fail'
echo "$@"
exit 1
